from .related import RelatedField
from .file import ImageField, FileField
from hvad.contrib.restframework import TranslatableModelSerializer
from django.db import models
from rest_framework import serializers


class FieldsOverrideMixin:
    serializer_field_mapping = {
        **serializers.ModelSerializer.serializer_field_mapping,
        models.FileField: FileField,
        models.ImageField: ImageField,
    }
    serializer_related_field = RelatedField


class TranslatableFieldsOverrideMixin(FieldsOverrideMixin):

    serializer_field_mapping = {
        **TranslatableModelSerializer.serializer_field_mapping,
        models.FileField: FileField,
        models.ImageField: ImageField,
    }



# Generated by Django 2.2.27 on 2022-03-09 16:16

import camomilla.fields
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("camomilla", "0007_auto_20220211_1622"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="article",
            options={"ordering": ["ordering"]},
        ),
        migrations.AlterModelOptions(
            name="category",
            options={"ordering": ["ordering"], "verbose_name_plural": "categories"},
        ),
        migrations.AlterModelOptions(
            name="page",
            options={
                "ordering": ["ordering"],
                "verbose_name": "Page",
                "verbose_name_plural": "Pages",
            },
        ),
        migrations.AddField(
            model_name="article",
            name="meta",
            field=camomilla.fields.JSONField(default=dict),
        ),
        migrations.AddField(
            model_name="article",
            name="ordering",
            field=models.PositiveIntegerField(default=0),
        ),
        migrations.AddField(
            model_name="category",
            name="meta",
            field=camomilla.fields.JSONField(default=dict),
        ),
        migrations.AddField(
            model_name="category",
            name="ordering",
            field=models.PositiveIntegerField(default=0),
        ),
        migrations.AddField(
            model_name="page",
            name="meta",
            field=camomilla.fields.JSONField(default=dict),
        ),
        migrations.AddField(
            model_name="page",
            name="ordering",
            field=models.PositiveIntegerField(default=0),
        ),
    ]



# Generated by Django 3.0 on 2022-09-02 10:00

from django.db import migrations
from django.contrib.postgres.operations import TrigramExtension


class Migration(migrations.Migration):

    dependencies = [
        ('camomilla', '0010_auto_20220802_1406'),
    ]

    operations = [
        TrigramExtension()
    ]



from ..models import Article, Category, Tag
from .base import BaseTranslatableModelSerializer


class TagSerializer(BaseTranslatableModelSerializer):
    class Meta:
        model = Tag
        fields = "__all__"


class CategorySerializer(BaseTranslatableModelSerializer):
    class Meta:
        model = Category
        fields = "__all__"


class ArticleSerializer(BaseTranslatableModelSerializer):
    class Meta:
        model = Article
        fields = "__all__"



from ..models import Content, Page
from .base import BaseTranslatableModelSerializer


class ContentSerializer(BaseTranslatableModelSerializer):
    class Meta:
        model = Content
        fields = "__all__"


class PageSerializer(BaseTranslatableModelSerializer):
    class Meta:
        model = Page
        fields = "__all__"



from hvad.contrib.restframework import TranslatableModelSerializer
from hvad.models import TranslatableModel
from rest_framework import serializers

from ..fields import FieldsOverrideMixin, TranslatableFieldsOverrideMixin
from ..mixins import (
    JSONFieldPatchMixin,
    LangInfoMixin,
    OrderingMixin,
    SetupEagerLoadingMixin,
    TranslationSetMixin,
    NestMixin,
)


def build_standard_model_serializer(self, model, depth):
    bases = (
        NestMixin,
        FieldsOverrideMixin,
        JSONFieldPatchMixin,
        OrderingMixin,
        SetupEagerLoadingMixin,
        serializers.ModelSerializer,
    )
    if issubclass(model, TranslatableModel):
        bases = (
            NestMixin,
            TranslatableFieldsOverrideMixin,
            JSONFieldPatchMixin,
            OrderingMixin,
            TranslatableModelSerializer,
        )
    return type(
        f"{model.__name__}StandardSerializer",
        bases,
        {
            "Meta": type(
                "Meta",
                (object,),
                {"model": model, "depth": depth, "fields": "__all__"},
            )
        },
    )


class BaseModelSerializer(
    NestMixin,
    FieldsOverrideMixin,
    JSONFieldPatchMixin,
    OrderingMixin,
    SetupEagerLoadingMixin,
    serializers.ModelSerializer,
):

    build_standard_model_serializer = build_standard_model_serializer


class BaseTranslatableModelSerializer(
    NestMixin,
    TranslatableFieldsOverrideMixin,
    JSONFieldPatchMixin,
    OrderingMixin,
    LangInfoMixin,
    TranslationSetMixin,
    TranslatableModelSerializer,
):
    build_standard_model_serializer = build_standard_model_serializer
